using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using System.IO;

namespace Nintenlord.LZ77_compressor
{
    public partial class Form1 : Form
    {
        String originalFile, outputFile;
        public enum actions { scan, compress, uncompress, check, lenght, none };

        public Form1()
        {
            InitializeComponent();
            textBox1.Text = "Inputfile.";
            textBox2.Text = "Outputfile.";
        }

        public Form1(string input)
        {
            InitializeComponent();
            textBox1.Text = input;
            originalFile = input;
            textBox2.Text = "Outputfile.";
        }

        private void button1_Click(object sender, EventArgs e)
        {
            OpenFileDialog openDialog = new OpenFileDialog();
            openDialog.Multiselect = false;
            openDialog.Title = "Open input file...";
            openDialog.Filter = "GBA ROMs|*.gba|All Files|*";
            if (originalFile != null && originalFile.Contains(@"\"))
            {
                openDialog.InitialDirectory = Path.GetDirectoryName(originalFile);
                openDialog.FileName = Path.GetFileName(originalFile); 
            }
            openDialog.ShowDialog();
            if (openDialog.FileNames.Length < 1)
                return;
            originalFile = openDialog.FileName;
            textBox1.Text = originalFile;
        }

        private void button2_Click(object sender, EventArgs e)
        {
            OpenFileDialog openDialog = new OpenFileDialog();
            openDialog.Title = "Open output file...";
            openDialog.Filter = "GBA ROMs|*.gba|Text files|*.txt|All Files|*";
            if (outputFile != null && outputFile.Contains(@"\"))
            {
                openDialog.InitialDirectory = Path.GetDirectoryName(outputFile);
                openDialog.FileName = Path.GetFileName(outputFile); 
            }
            openDialog.CheckFileExists = false;
            openDialog.Multiselect = false;
            openDialog.ShowDialog();
            if (openDialog.FileNames.Length < 1)
                return;
            outputFile = openDialog.FileName;
            textBox2.Text = outputFile;
        }

        private void button3_Click(object sender, EventArgs e)
        {
            string message;
            if (radioButton1.Checked)
            {
                //action = actions.compress;
                if (Program.Compress(originalFile, outputFile, (int)numericUpDown1.Value, (int)numericUpDown2.Value, (int)numericUpDown3.Value))
                    message = "Compression was successful";
                else
                    message = "Compression failed";
            }
            else if (radioButton2.Checked)
            {
                //action = actions.uncompress;
                if (Program.Decompress(originalFile, outputFile, (int)numericUpDown1.Value, (int)numericUpDown3.Value))
                    message = "Decompression was successful";
                else
                    message = "Decompression failed";
            }
            else if (radioButton3.Checked)
            {
                int[] scanResults = Program.Scan(originalFile, (int)numericUpDown1.Value, (int)numericUpDown2.Value);
                if (scanResults != null)
                {
                    StreamWriter sw = new StreamWriter(outputFile);
                    for (int i = 0; i < scanResults.Length; i++)
                        sw.WriteLine(Convert.ToString(scanResults[i], 16));
                    message = "Scanning was successful.";
                }
                else
                    message = "Error in scanning.";
                //action = actions.scan;
            }
            else if (radioButton4.Checked)
            {
                message = "Offset " + Convert.ToString((int)numericUpDown1.Value, 16) + " can";
                if (!Program.Check(originalFile, (int)numericUpDown1.Value))
                {
                    message += "'t";
                }
                message += " be decompressed.";
                //action = actions.check;

            }
            else if (radioButton5.Checked)
            {
                int lenght = Program.Length(originalFile, (int)numericUpDown1.Value);
                if (lenght == -1)
                    message = "That offset can't be decompressed.";
                else
                    message = "The length of the compressed data is 0x" + Convert.ToString(lenght,16) + ".";
                //action = actions.lenght;
            }
            else
            {
                //action = actions.none;
                message = "No action selected.";
            }
            MessageBox.Show(message);
        }

        private void button4_Click(object sender, EventArgs e)
        {
            Application.Exit();
        }

        private void textBox1_TextChanged(object sender, EventArgs e)
        {
            originalFile = textBox1.Text;
        }

        private void textBox2_TextChanged(object sender, EventArgs e)
        {
            outputFile = textBox2.Text;
        }
    }
}